.simply-countdown-circle {
  --sc-circle-primary: #6366f1;
  --sc-circle-secondary: #818cf8;
  --sc-circle-bg: #1e1b4b;
  --sc-circle-text: #fff;

  display: flex;
  flex-wrap: wrap;
  justify-content: center;
  gap: 1.5rem;
  font-family: "Inter", sans-serif;
}

.simply-countdown-circle > .simply-section {
  position: relative;
  width: 100px;
  height: 100px;
  padding: 1rem;
  display: flex;
  align-items: center;
  justify-content: center;
  flex-direction: column;
  border-radius: 50%;
  background: linear-gradient(45deg, var(--sc-circle-primary), var(--sc-circle-secondary));
  box-shadow: 0 0 25px -5px var(--sc-circle-primary);
  animation: pulse-circle 2s cubic-bezier(0.4, 0, 0.6, 1) infinite;
}

.simply-countdown-circle > .simply-section::before {
  content: "";
  position: absolute;
  inset: 6px;
  border-radius: 50%;
  background: var(--sc-circle-bg);
  z-index: 0;
}

.simply-countdown-circle > .simply-section > div {
  position: relative;
  z-index: 1;
  color: var(--sc-circle-text);
  text-align: center;
}

.simply-countdown-circle .simply-amount {
  display: block;
  font-size: 1.75rem;
  font-weight: 700;
  line-height: 1;
  background: linear-gradient(to right, var(--sc-circle-primary), var(--sc-circle-secondary));
  -webkit-background-clip: text;
  background-clip: text;
  -webkit-text-fill-color: transparent;
}

.simply-countdown-circle .simply-word {
  font-size: 0.7rem;
  text-transform: uppercase;
  letter-spacing: 0.05em;
  opacity: 0.8;
}

@keyframes pulse-circle {
  0%,
  100% {
    transform: scale(1);
    opacity: 1;
  }
  50% {
    transform: scale(0.98);
    opacity: 0.9;
  }
}
