/**
* Project : simply-countdown
* File : simplyCountdown.theme.dark
* Author : Vincent Loy <vincent.loy1@gmail.com>
* Theme : Dark Modern
*/

.simply-countdown-dark {
  overflow: hidden;
  display: flex;
  flex-wrap: wrap;
  justify-content: center;
  gap: 1.25rem;
  font-family: "Inter", system-ui, -apple-system, sans-serif;
}

.simply-countdown-dark > .simply-section {
  width: 65px;
  height: 65px;
  padding: 1.5rem;
  display: flex;
  align-items: center;
  justify-content: center;
  background: rgba(15, 23, 42, 0.75);
  border: 1px solid rgba(51, 65, 85, 0.6);
  border-radius: 1rem;
  box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.2), 0 2px 4px -1px rgba(0, 0, 0, 0.1), 0 0 0 1px rgba(255, 255, 255, 0.05);
  transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1);
  backdrop-filter: blur(10px);
}

.simply-countdown-dark > .simply-section > div {
  display: flex;
  flex-direction: column;
  line-height: 1;
  align-items: center;
}

.simply-countdown-dark > .simply-section .simply-amount {
  font-size: 1.5rem;
  font-weight: 700;
  color: #f1f5f9;
  line-height: 1.2;
  letter-spacing: -0.025em;
}

.simply-countdown-dark > .simply-section .simply-word {
  font-size: 0.6rem;
  font-weight: 500;
  color: #94a3b8;
  text-transform: uppercase;
  letter-spacing: 0.1em;
}

@media (min-width: 640px) {
  .simply-countdown-dark > .simply-section {
    width: 75px;
    height: 75px;
    padding: 1.75rem;
  }

  .simply-countdown-dark > .simply-section .simply-amount {
    font-size: 1.75rem;
  }

  .simply-countdown-dark > .simply-section .simply-word {
    font-size: 0.75rem;
  }
}

@media (min-width: 1024px) {
  .simply-countdown-dark > .simply-section {
    width: 90px;
    height: 90px;
    padding: 2rem;
  }

  .simply-countdown-dark > .simply-section .simply-amount {
    font-size: 2rem;
  }

  .simply-countdown-dark > .simply-section .simply-word {
    font-size: 0.8rem;
  }
}
