{% extends 'cjkcms/blocks/base_block.html' %}
{% load wagtailcore_tags wagtailimages_tags %}

{% block block_render %}

    <div class="card-group {{self.settings.custom_css_class}}"
     {% if self.settings.custom_id %}
     id="{{self.settings.custom_id}}"
     {% endif %}>
        {% for page in pages %}
        {% with page.specific as article %}
            {% include "cjkcms/blocks/article_block_card.html" %}
        {% endwith %}
        {% endfor %}
    </div>

{% endblock %}
